export declare enum SahhaEnvironment {
    development = "development",
    production = "production"
}
export declare enum SahhaSensor {
    sleep = "sleep",
    pedometer = "pedometer",
    device = "device"
}
export declare enum SahhaSensorStatus {
    pending = 0,
    unavailable = 1,
    disabled = 2,
    enabled = 3
}
export interface SahhaSettings {
    environment: SahhaEnvironment;
    sensors?: SahhaSensor[];
    postSensorDataManually?: boolean;
}
export interface SahhaDemographic {
    age?: number;
    gender?: string;
    country?: string;
    birthCountry?: string;
}
export interface SahhaPlugin {
    configure(options: {
        settings: SahhaSettings;
    }): Promise<{
        success: boolean;
    }>;
    authenticate(options: {
        profileToken: string;
        refreshToken: string;
    }): Promise<{
        success: boolean;
    }>;
    getDemographic(): Promise<{
        value: string;
    }>;
    postDemographic(options: {
        demographic: SahhaDemographic;
    }): Promise<{
        success: boolean;
    }>;
    getSensorStatus(options: {
        sensor: SahhaSensor;
    }): Promise<{
        status: SahhaSensorStatus;
    }>;
    enableSensor(options: {
        sensor: SahhaSensor;
    }): Promise<{
        status: SahhaSensorStatus;
    }>;
    postSensorData(options?: {
        sensors: [SahhaSensor];
    }): Promise<{
        success: boolean;
    }>;
    analyze(options?: {
        startDate: number;
        endDate: number;
    }): Promise<{
        value: string;
    }>;
    openAppSettings(): Promise<void>;
}
